@@ -3,4 +3,4 @@ from django.apps import AppConfig
 
 class PostsConfig(AppConfig):
     default_auto_field = 'django.db.models.BigAutoField'
-    name = 'django_posts_api.posts'
+    name = 'django_posts_api_posts'
